# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.models.llm_eval import LLMEval

class TestLLMEval(unittest.TestCase):
    """LLMEval unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> LLMEval:
        """Test LLMEval
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `LLMEval`
        """
        model = LLMEval()
        if include_optional:
            return LLMEval(
                name = '',
                model_name = '',
                model_provider = 'anthropic',
                instructions = '',
                variables = [
                    ''
                    ],
                tags = [
                    ''
                    ],
                config = arthur_client.api_bindings.models.llm_base_config_settings.LLMBaseConfigSettings(
                    timeout = 1.337, 
                    temperature = 1.337, 
                    top_p = 1.337, 
                    max_tokens = 56, 
                    stop = '', 
                    presence_penalty = 1.337, 
                    frequency_penalty = 1.337, 
                    seed = 56, 
                    logprobs = True, 
                    top_logprobs = 56, 
                    logit_bias = [
                        arthur_client.api_bindings.models.logit_bias_item.LogitBiasItem(
                            token_id = 56, 
                            bias = -100.0, )
                        ], 
                    max_completion_tokens = 56, 
                    reasoning_effort = 'none', 
                    thinking = arthur_client.api_bindings.models.anthropic_thinking_param.AnthropicThinkingParam(
                        type = 'enabled', 
                        budget_tokens = 56, ), ),
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                deleted_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                version = 56
            )
        else:
            return LLMEval(
                name = '',
                model_name = '',
                model_provider = 'anthropic',
                instructions = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
        )
        """

    def testLLMEval(self):
        """Test LLMEval"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.models.tool import Tool

class TestTool(unittest.TestCase):
    """Tool unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Tool:
        """Test Tool
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Tool`
        """
        model = Tool()
        if include_optional:
            return Tool(
                name = '',
                arguments = [
                    arthur_client.api_bindings.models.tool_argument.ToolArgument(
                        name = '', 
                        type = '', )
                    ]
            )
        else:
            return Tool(
                name = '',
        )
        """

    def testTool(self):
        """Test Tool"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
